@@ -4,8 +4,10 @@ import           Test.Hspec
 import           System.IO
 import           System.IO.Silently
 import           System.Directory
+import           System.IO.Temp
 
 import           Control.Exception
+import           Control.Monad
 
 main :: IO ()
 main = hspec spec
@@ -26,3 +28,11 @@ spec = do
   describe "capture" $ do
     it "captures stdout" $ do
       capture (putStr "foo" >> return 23) `shouldReturn` ("foo", 23 :: Int)
+
+  describe "hCapture" $ do
+    forM_ [NoBuffering, LineBuffering, BlockBuffering Nothing] $ \buffering -> do
+      it ("preserves " ++ show buffering) $ do
+        withSystemTempFile "silently" $ \_file h -> do
+          hSetBuffering h buffering
+          _ <- hCapture [h] (return ())
+          hGetBuffering h `shouldReturn` buffering
